@@ -7,12 +7,12 @@ use URI::Escape 'uri_unescape';
 use URI::file;
 #use Search::Elasticsearch::TestServer;
 
-use Dancer::SearchApp::Defaults 'default_index';
+use Dancer::SearchApp::Defaults 'get_defaults';
 
 use Dancer::SearchApp::Entry;
 
 use vars qw($VERSION $es %indices);
-$VERSION = '0.04';
+$VERSION = '0.05';
 
 =head1 NAME
 
@@ -68,14 +68,19 @@ as C<SEARCHAPP_ES_NODES>.
 use Data::Dumper;
 $Data::Dumper::Sortkeys = 1;
 
+my $config = get_defaults(
+    env      => \%ENV,
+    config   => config(),
+    #defaults => \%
+    names => [
+        ['elastic_search/index' => 'elastic_search/index' => 'SEARCHAPP_ES_INDEX', 'searchapp'],
+        ['elastic_search/nodes' => 'elastic_search/nodes' => 'SEARCHAPP_ES_NODES', 'localhost:9200'],
+    ],
+);
+
 sub search {
     if( ! $es ) {
-        my $nodes;
-        if( $nodes = $ENV{SEARCHAPP_ES_NODES} ) {
-            $nodes = [ split /;/, $nodes ];
-        } else {
-            $nodes = config->{nodes} || [];
-        };
+        my $nodes = config->{elastic_search}->{nodes};
         $es = Search::Elasticsearch->new(
             nodes => $nodes,
         );
@@ -84,7 +89,7 @@ sub search {
     $es
 };
 
-$Template::Stash::PRIVATE = 1;
+$Template::Stash::PRIVATE = $Template::Stash::PRIVATE = 1;
 
 get '/' => sub {
     # Later, separate out the code paths between
@@ -114,7 +119,7 @@ get '/' => sub {
         };
         
         # Move this to an async query, later
-        my $index = config->{elastic_search}->{index} || default_index;
+        my $index = config->{elastic_search}->{index};
         $results = search->search(
             # Wir suchen in allen Sprachindices
             index => [ grep { /^\Q$index\E/ } sort keys %indices ],
