@@ -3,7 +3,7 @@ use strict;
 use Moo;
 
 use vars qw($VERSION $es $server);
-$VERSION = '0.04';
+$VERSION = '0.05';
 
 =head1 NAME
 
@@ -52,7 +52,10 @@ has url => (
     #isa => 'Str',
 );
 
+{
+no warnings 'once';
 *id = \*url;
+}
 
 has mime_type => (
     is => 'ro',
